function [K] = sobolev(coord,dAlpha)

%function K = sobolev(coord,dAlpha)
%
% Computes a sobolev kernel matrix from the input coordinates
%
%INPUTS
% coord  = a matrix containing all samples as rows
% dAlpha = weight of the 2nd derivative
%
%OUTPUTS
% K = the sobolev kernel matrix 
%
%
% For more info, see www.kernel-methods.net
%
%Author: Frank-Michael Schleif

n = size(coord,1);
K = coord*coord';
for(i=1:n)
	Xd(i,:) = diffStepVec(diffStepVec(coord(i,:),1),1);        
end  
K = K + dAlpha * (Xd * Xd');

function dF = diffStepVec(vX,iStepsize)
iLengthS = length(vX);
dF       = ones(size(vX));
for(i=1:iLengthS) % (x_i - x_i-1) + (x_i+1 - x_i)
    dF(:,i) = (vX(:,i) - vX(:,mod(i-iStepsize,iLengthS)+1))+ (vX(:,mod(i+iStepsize,iLengthS)+1) - vX(:,i));
end
