function [C,W] = sobolev_nystroem(coord,dAlpha,indices)

%function K = sobolev(coord,dAlpha)
%
% Computes a sobolev kernel matrix from the input coordinates
%
%INPUTS
% coord  = a matrix containing all samples as rows
% dAlpha = weight of the 2nd derivative
%
%OUTPUTS
% K = the sobolev kernel matrix 
% nystroem variant - lazy version
%
% For more info, see www.kernel-methods.net
%
%Author: Frank-Michael Schleif
if(length(indices) > 1000)
    error('You indices selection is very large - consider a smaller set - stop now');
    return;
end
n = size(coord,1);
iNumberOfLandmarks = length(indices);
W = zeros(iNumberOfLandmarks);
C = zeros(n,iNumberOfLandmarks);

K = coord*coord';
for(i=1:n)
	Xd(i,:) = diffStepVec(diffStepVec(coord(i,:),1),1);        
end  
K = K + dAlpha * (Xd * Xd');
C      = K(:,indices);         % C
W      = pinv(K(indices,indices)); % W^+_k

function dF = diffStepVec(vX,iStepsize)
iLengthS = length(vX);
dF       = ones(size(vX));
for(i=1:iLengthS) % (x_i - x_i-1) + (x_i+1 - x_i)
    dF(:,i) = (vX(:,i) - vX(:,mod(i-iStepsize,iLengthS)+1))+ (vX(:,mod(i+iStepsize,iLengthS)+1) - vX(:,i));
end
