function [IAll,mDistancesToPrototypesAll] = apply_kglvq_2010(oModel,mFullData,varargin)
bNystroem       = oModel.bNystroem;
bMuchMemory     = true;
fKernel         = oModel.fKernel;
iNrOfPrototypes = size(oModel.G,1);
try
    if(nargin>2)
        iSplits = 10;
    else
        iSplits = 1;
    end
    iNrOfAllDataPoints = size(mFullData,1);
    iStartBlock = 1;
    iBlockSize  = ceil(iNrOfAllDataPoints/iSplits);
    IAll        = zeros(iNrOfAllDataPoints,1); 
    mDistancesToPrototypesAll = zeros(iNrOfAllDataPoints, iNrOfPrototypes);
    for(s=1:iSplits)
        if(iStartBlock+iBlockSize > iNrOfAllDataPoints)
            iBlockSize = iNrOfAllDataPoints - iStartBlock +1;
        end
        if(iBlockSize < 1)
            continue; % nothing more to do
        end
        dat = mFullData(iStartBlock:iStartBlock+iBlockSize-1,:);
        iNrOfDataPoints = size(dat,1);
        iNrOfDataPointsTrain = size(oModel.oTrain.data,1);
        I = zeros(iNrOfDataPoints,1); 
        mDistancesToPrototypes = zeros(iNrOfDataPoints,iNrOfPrototypes);
        N        = iNrOfDataPoints + iNrOfDataPointsTrain;
        dSampleRate = 0.05; % fixed
        M        = ceil(N * dSampleRate); % number of projection dimensions left
        if(M == 0)
            M = 1;
        end

        P        = randperm(N);
        ind      = P(1:M);
        if(~bNystroem)
            K  = fKernel([dat; oModel.oTrain.data]);    
            nyDis{1} = K(:,ind);         % C
            nyDis{2} = pinv(K(ind,ind)); % W^+_k
        else
            [C,W]    = fKernel([dat; oModel.oTrain.data],ind);
            nyDis{1} = C;
            nyDis{2} = W;
        end
        nyDis{3} = P;

        % self products test data
        for(l=1:iNrOfDataPoints)
            vDiag(l) = nyDis{1}(l,:)*nyDis{2} * nyDis{1}(l,:)';
        end
        vOnes = ones(iNrOfDataPoints,1);
        % products train to test data
        vInnerProductsData   = zeros(iNrOfDataPointsTrain,iNrOfDataPoints);
        for(i=1:iNrOfDataPointsTrain)
                 vTemp = nyDis{1}(iNrOfDataPoints+i,:)*nyDis{2};
                 if(~bMuchMemory)
                     for(l=1:iNrOfDataPoints)
                         vInnerProductsData(i,l) =  vTemp * nyDis{1}(l,:)';
                     end
                 else
                     vInnerProductsData(i,:) = sum(vTemp(vOnes,:) .* nyDis{1}([1:iNrOfDataPoints],:),2)';
                 end
        end

        vDistTmp = zeros(size(oModel.G));
        for i=1:iNrOfPrototypes
                vDistTmp(i,:) =((oModel.G(i,:)*oModel.K{1})*oModel.K{2})*oModel.K{1}'; 
        end
        vTemp = diag(oModel.G * vDistTmp');
        for j=1:iNrOfDataPoints    
            vDistancesToPrototypes = zeros(iNrOfPrototypes,1);
            for(i=1:iNrOfPrototypes)
                vDistancesToPrototypes(i) = (vDiag(j)  -2 * sum((oModel.G(i,:)) .* vInnerProductsData(:,j)') +  vTemp(i));
                mDistancesToPrototypes(j,i) = vDistancesToPrototypes(i);
            end
            [dCorr, iMinCorr]  = min(vDistancesToPrototypes);    
            I(j) = iMinCorr;
        end
        IAll(iStartBlock:iStartBlock+iBlockSize-1) = I; 
        mDistancesToPrototypesAll(iStartBlock:iStartBlock+iBlockSize-1,:) = mDistancesToPrototypes;
        iStartBlock = iStartBlock+iBlockSize;
    end
catch sException
    warning('apply_kglvq_2010',sException.message)
    warning('apply_kglvq_2010','If you run out of memory - add - 1 -  as the last parameter as a few memory flag');
end